Module error

Module error 

Error handling utilities with automatic rich display.

This module provides the ErrorBoundary type that wraps operations and automatically displays errors beautifully on failure using the configured console and theme.

Structs

ErrorBoundary
Wraps operations and displays errors beautifully on failure.